# KANama

Fusing Kolmogorov–Arnold Networks with Meta's Llama model for next-level AI performance and versatility.

## Usage

Install via PyPi:

`pip install kanama`

## Available modeels

- KANamav1: The basic Llama3.1 model mith a KAN model instead of a basic MLP.
- KANamav2: More optimized then v1.
- KANamav3: A Llama3.1 model mith a KAN and a dynaicaly adjusting Softmax Temperature.
- KANamav4: More optimized then v1.
- KANaMoEv1: v4 but with a MoE architecture.

## Examples

For a good introduction, you can look into the example files.
